@@ -471,11 +471,10 @@ def floats(
 
     if allow_nan is None:
         allow_nan = bool(min_value is None and max_value is None)
-    elif allow_nan:
-        if min_value is not None or max_value is not None:
-            raise InvalidArgument(
-                "Cannot have allow_nan=%r, with min_value or max_value" % (allow_nan)
-            )
+    elif allow_nan and (min_value is not None or max_value is not None):
+        raise InvalidArgument(
+            "Cannot have allow_nan=%r, with min_value or max_value" % (allow_nan)
+        )
 
     if width not in (16, 32, 64):
         raise InvalidArgument(
@@ -1815,6 +1814,12 @@ def composite(f: Callable[..., Ex]) -> Callable[..., SearchStrategy[Ex]]:
     Examples from this strategy shrink by shrinking the output of each draw
     call.
     """
+    if isinstance(f, (classmethod, staticmethod)):
+        special_method = type(f)
+        f = f.__func__
+    else:
+        special_method = None
+
     argspec = getfullargspec(f)
 
     if argspec.defaults is not None and len(argspec.defaults) == len(argspec.args):
@@ -1838,6 +1843,8 @@ def composite(f: Callable[..., Ex]) -> Callable[..., SearchStrategy[Ex]]:
         return CompositeStrategy(f, args, kwargs)
 
     accept.__module__ = f.__module__
+    if special_method is not None:
+        return special_method(accept)
     return accept
 
 
